@@ -1,4 +1,4 @@
-from marshmallow import EXCLUDE, fields, Schema
+from marshmallow import EXCLUDE, fields, Schema, pre_load
 
 from livestyled.models.audience import Audience
 from livestyled.schemas.fields import RelatedResourceLinkField
@@ -9,6 +9,11 @@ class AudienceRealityValuesValueSchema(Schema):
     operator = fields.String()
     value = fields.String()
 
+    @pre_load
+    def pre_process_value(self, data, **kwarg):
+        data['value'] = str(data['value'])
+        return data
+
 
 class AudienceRealityValuesSchema(Schema):
     reality = RelatedResourceLinkField(schema=RealitySchema, microservice_aware=True)
